"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFetchApi = void 0;
const fetch_1 = require("./fetch");
/**
 * Creates new Pilet API extensions for fetch.
 * @param config The custom fetch configuration, if any.
 */
function createFetchApi(config = {}) {
    return (context) => {
        return {
            fetch(path, options = {}) {
                const originalHeaders = options.headers || {};
                const headerPromises = [];
                context.emit('before-fetch', {
                    headers: originalHeaders,
                    method: options.method || 'GET',
                    target: path,
                    setHeaders(headers) {
                        if (headers) {
                            headerPromises.push(headers);
                        }
                    },
                });
                return Promise.all(headerPromises)
                    .then((newHeaders) => {
                    const headers = newHeaders.reduce((obj, header) => {
                        if (typeof header === 'object' && header) {
                            return Object.assign(Object.assign({}, obj), header);
                        }
                        return obj;
                    }, originalHeaders);
                    return Object.assign(Object.assign({}, options), { headers });
                })
                    .then((options) => (0, fetch_1.httpFetch)(config, path, options));
            },
        };
    };
}
exports.createFetchApi = createFetchApi;
//# sourceMappingURL=create.js.map